@@ -11,7 +11,9 @@ use 5.006;
 use strict;
 use warnings;
 package Metabase::Fact::Hash;
-our $VERSION = '0.011';
+BEGIN {
+  $Metabase::Fact::Hash::VERSION = '0.012';
+}
 # ABSTRACT: fact subtype for simple hashes
 
 use Carp ();
@@ -61,7 +63,7 @@ Metabase::Fact::Hash - fact subtype for simple hashes
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -149,6 +151,7 @@ existing test-file that illustrates the bug or desired feature.
 
   David Golden <dagolden@cpan.org>
   Ricardo Signes <rjbs@cpan.org>
+  H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
