@@ -11,7 +11,9 @@ use 5.006;
 use strict;
 use warnings;
 package Metabase::Fact::String;
-our $VERSION = '0.011';
+BEGIN {
+  $Metabase::Fact::String::VERSION = '0.012';
+}
 # ABSTRACT: fact subtype for simple strings
 
 use Carp ();
@@ -52,7 +54,7 @@ Metabase::Fact::String - fact subtype for simple strings
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -108,6 +110,7 @@ existing test-file that illustrates the bug or desired feature.
 
   David Golden <dagolden@cpan.org>
   Ricardo Signes <rjbs@cpan.org>
+  H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
