@@ -11,7 +11,9 @@ use 5.006;
 use strict;
 use warnings;
 package Metabase::Resource::metabase::user;
-our $VERSION = '0.011';
+BEGIN {
+  $Metabase::Resource::metabase::user::VERSION = '0.012';
+}
 # ABSTRACT: class for Metabase user profiles
 
 use Carp ();
@@ -46,7 +48,7 @@ Metabase::Resource::metabase::user - class for Metabase user profiles
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -82,6 +84,7 @@ existing test-file that illustrates the bug or desired feature.
 
   David Golden <dagolden@cpan.org>
   Ricardo Signes <rjbs@cpan.org>
+  H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
