@@ -11,7 +11,9 @@ use 5.006;
 use strict;
 use warnings;
 package Metabase::User::Profile;
-our $VERSION = '0.011';
+BEGIN {
+  $Metabase::User::Profile::VERSION = '0.012';
+}
 # ABSTRACT: Metabase report class for user-related facts
 
 use Carp ();
@@ -82,7 +84,7 @@ Metabase::User::Profile - Metabase report class for user-related facts
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -157,6 +159,7 @@ existing test-file that illustrates the bug or desired feature.
 
   David Golden <dagolden@cpan.org>
   Ricardo Signes <rjbs@cpan.org>
+  H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
